@@ -7,7 +7,7 @@ package Spreadsheet::WriteExcel::Format;
 #
 # Used in conjunction with Spreadsheet::WriteExcel
 #
-# Copyright 2000-2006, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2008, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -24,7 +24,7 @@ use Carp;
 use vars qw($AUTOLOAD $VERSION @ISA);
 @ISA = qw(Exporter);
 
-$VERSION = '2.16';
+$VERSION = '2.22';
 
 ###############################################################################
 #
@@ -91,6 +91,8 @@ sub new {
                     _diag_color     => 0x40,
                     _diag_border    => 0,
 
+                    _font_only      => 0,
+
                     # Temp code to prevent merged formats in non-merged cells.
                     _used_merge     => 0,
 
@@ -118,9 +120,17 @@ sub copy {
     return unless defined $other;
     return unless (ref($self) eq ref($other));
 
-    my $xf = $self->{_xf_index};    # Store XF index assigned by Workbook.pm
-    %$self = %$other;               # Copy properties
-    $self->{_xf_index} = $xf;       # Restore XF index
+    # Store the properties that we don't want overwritten.
+    my $xf                  = $self->{_xf_index};
+    my $merge_range         = $self->{_merge_range};
+    my $used_merge          = $self->{_used_merge};
+
+    %$self                  = %$other; # Copy properties
+
+    # Restore saved properties.
+    $self->{_xf_index}      = $xf;
+    $self->{_merge_range}   = $merge_range;
+    $self->{_used_merge}    = $used_merge;
 }
 
 
@@ -700,26 +710,10 @@ sub set_properties {
         # Strip leading "-" from Tk style properties e.g. -color => 'red'.
         $key =~ s/^-//;
 
-
-        # Make sure method names are alphanumeric characters only, in case
-        # tainted data is passed to the eval().
-        #
-        die "Unknown method: \$self->set_$key\n" if $key =~ /\W/;
-
-
-        # Evaling all $values as a strings gets around the problem of some
-        # numerical format strings being evaluated as numbers, for example
-        # "00000" for a zip code.
-        #
-        if (defined $value) {
-            eval "\$self->set_$key('$value')";
-        }
-        else {
-            eval "\$self->set_$key(undef)";
-        }
-
-        die $@ if $@; # Rethrow the eval error.
-    }
+        # Create a sub to set the property.
+        my $sub = \&{"set_$key"};
+        $sub->($self, $value);
+   }
 }
 
 
@@ -809,6 +803,6 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
- MM-MMVI, John McNamara.
+ MM-MMVIII, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
